@@ -1,21 +1,17 @@
 /*
-    Copyright 2005-2014 Intel Corporation.  All Rights Reserved.
+    Copyright (c) 2005-2019 Intel Corporation
 
-    This file is part of Threading Building Blocks. Threading Building Blocks is free software;
-    you can redistribute it and/or modify it under the terms of the GNU General Public License
-    version 2  as  published  by  the  Free Software Foundation.  Threading Building Blocks is
-    distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
-    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-    See  the GNU General Public License for more details.   You should have received a copy of
-    the  GNU General Public License along with Threading Building Blocks; if not, write to the
-    Free Software Foundation, Inc.,  51 Franklin St,  Fifth Floor,  Boston,  MA 02110-1301 USA
+    Licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
+    You may obtain a copy of the License at
 
-    As a special exception,  you may use this file  as part of a free software library without
-    restriction.  Specifically,  if other files instantiate templates  or use macros or inline
-    functions from this file, or you compile this file and link it with other files to produce
-    an executable,  this file does not by itself cause the resulting executable to be covered
-    by the GNU General Public License. This exception does not however invalidate any other
-    reasons why the executable file might be covered by the GNU General Public License.
+        http://www.apache.org/licenses/LICENSE-2.0
+
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
+    limitations under the License.
 */
 
 #include "harness_task.h"
@@ -34,7 +30,7 @@ class EnqueuedTask : public tbb::task {
     task* my_successor;
     int my_enqueue_order;
     int* my_track;
-    tbb::task* execute() {
+    tbb::task* execute() __TBB_override {
         // Capture execution order in the very beginning
         int execution_order = 2 - my_successor->decrement_ref_count();
         // Create some local work.
@@ -134,7 +130,7 @@ void TestEnqueue( int p ) {
         tbb::task_scheduler_init init(p);
         EnqueuedTask::nCompletedPairs = EnqueuedTask::nOrderedPairs = 0;
         for(int i=0; i<nTracks; ++i) {
-            TaskTracks[i] = -1; // to accomodate for the starting call
+            TaskTracks[i] = -1; // to accommodate for the starting call
             EnqueuedTask::FireTwoTasks(TaskTracks+i);
         }
         ProgressMonitor pm;
@@ -166,7 +162,7 @@ void TestEnqueue( int p ) {
 ////////////////////////////////////////////////////////////////////////////////
 // Tests for Fire-And-Forget scheduling functionality
 
-const int NumRepeats = 200;
+int NumRepeats = 200;
 const int MaxNumThreads = 16;
 static volatile bool Finished[MaxNumThreads] = {};
 
@@ -174,8 +170,8 @@ static volatile bool CanStart;
 
 //! Custom user task interface
 class ITask {
-public: 
-    virtual ~ITask() {} 
+public:
+    virtual ~ITask() {}
     virtual void Execute() = 0;
     virtual void Release() { delete this; }
 };
@@ -185,7 +181,7 @@ class TestTask : public ITask {
 public:
     TestTask ( volatile bool *pDone ) : m_pDone(pDone) {}
 
-    /* override */ void Execute() {
+    void Execute() __TBB_override {
         *m_pDone = true;
     }
 };
@@ -195,7 +191,7 @@ class CarrierTask : public tbb::task {
 public:
     CarrierTask(ITask* pTask) : m_pTask(pTask) {}
 
-    /*override*/ task* execute() {
+    task* execute() __TBB_override {
         m_pTask->Execute();
         m_pTask->Release();
         return NULL;
@@ -207,7 +203,7 @@ class SpawnerTask : public ITask {
 public:
     SpawnerTask(ITask* job) : m_taskToSpawn(job) {}
 
-    void Execute() {
+    void Execute() __TBB_override {
         while ( !CanStart )
             __TBB_Yield();
         Harness::Sleep(10); // increases probability of the bug
@@ -256,7 +252,7 @@ void TestCascadedEnqueue () {
 
 class DummyTask : public tbb::task {
 public:
-    task *execute() {
+    task *execute() __TBB_override {
         Harness::Sleep(1);
         return NULL;
     }
@@ -273,10 +269,10 @@ public:
 };
 
 //! Test for enqueuing children of the same root from different master threads
-void TestSharedRoot ( int p ) { 
+void TestSharedRoot ( int p ) {
     REMARK("Testing enqueuing siblings from different masters\n");
     tbb::task_scheduler_init init(p);
-    tbb::task *root =  new ( tbb::task::allocate_root() ) tbb::empty_task; 
+    tbb::task *root =  new ( tbb::task::allocate_root() ) tbb::empty_task;
     root->set_ref_count(1);
     for( int n = MinThread; n <= MaxThread; ++n ) {
         REMARK("%d masters, %d requested workers\r", n, p-1);
@@ -290,7 +286,7 @@ void TestSharedRoot ( int p ) {
 class BlockingTask : public tbb::task {
     Harness::SpinBarrier &m_Barrier;
 
-    tbb::task* execute () {
+    tbb::task* execute () __TBB_override {
         m_Barrier.wait();
         return 0;
     }
@@ -305,10 +301,10 @@ void TestDequeueByMaster () {
     REMARK("Testing task dequeuing by master\n");
     tbb::task_scheduler_init init(1);
     Harness::SpinBarrier bar(2);
-    tbb::task &r = *new ( tbb::task::allocate_root() ) tbb::empty_task; 
+    tbb::task &r = *new ( tbb::task::allocate_root() ) tbb::empty_task;
     r.set_ref_count(3);
-    tbb::task::enqueue( *new(r.allocate_child()) BlockingTask(bar) ); 
-    tbb::task::enqueue( *new(r.allocate_child()) BlockingTask(bar) ); 
+    tbb::task::enqueue( *new(r.allocate_child()) BlockingTask(bar) );
+    tbb::task::enqueue( *new(r.allocate_child()) BlockingTask(bar) );
     r.wait_for_all();
     tbb::task::destroy(r);
 }
@@ -325,7 +321,7 @@ struct Functor : NoAssign
 {
     Harness::SpinBarrier &my_barrier;
     Functor(Harness::SpinBarrier &a_barrier) : my_barrier(a_barrier) { }
-    void operator()(const tbb::blocked_range<int>& r) const 
+    void operator()(const tbb::blocked_range<int>& r) const
     {
         ASSERT(r.size() == 1, NULL);
         // allocate_root() uses current context of parallel_for which is destroyed when it finishes.
@@ -341,6 +337,8 @@ void TestWakeups()
     tbb::task_scheduler_init my(tbb::task_scheduler_init::deferred);
     if( tbb::task_scheduler_init::default_num_threads() <= NUM_TASKS )
         my.initialize(NUM_TASKS*2);
+    else // workaround issue #1996 for TestCascadedEnqueue
+        my.initialize(tbb::task_scheduler_init::default_num_threads()+1);
     Harness::SpinBarrier barrier(NUM_TASKS);
     REMARK("Missing wake-up: affinity_partitioner\n");
     tbb::affinity_partitioner aff;
@@ -354,13 +352,25 @@ void TestWakeups()
         tbb::parallel_for(tbb::blocked_range<int>(0, NUM_TASKS), Functor(barrier)); // auto
 }
 
+#include "tbb/global_control.h"
+
 int TestMain () {
-    TestWakeups();
-    TestDequeueByMaster();
-    TestCascadedEnqueue();
-    for( int p=MinThread; p<=MaxThread; ++p ) {
-        TestEnqueue(p);
-        TestSharedRoot(p);
+
+    TestWakeups();         // 1st because requests oversubscription
+    for (int i=0; i<2; i++) {
+        tbb::global_control *c = i?
+            new tbb::global_control(tbb::global_control::max_allowed_parallelism, 1) : NULL;
+        if (i) // decrease workload for max_allowed_parallelism == 1
+            NumRepeats = 10;
+
+        TestCascadedEnqueue(); // needs oversubscription
+        if (!c)
+            TestDequeueByMaster(); // no oversubscription needed
+        for( int p=MinThread; p<=MaxThread; ++p ) {
+            TestEnqueue(p);
+            TestSharedRoot(p);
+        }
+        delete c;
     }
     return Harness::Done;
 }
